===========
policy.yaml
===========

Use the ``policy.yaml`` file to define additional access controls that apply to
the Container Infrastructure Management service:

.. literalinclude:: ../../_static/magnum.policy.yaml.sample

